@@ -20,8 +20,8 @@
 #include <bakery/App/Dialog_OfferSave.h>
 #include <bakery/App/Dialog_OverwriteFile.h>
 #include <gconfmm.h>
-#include <libgnomevfsmm.h>
 #include <libintl.h>
+#include <fstream>
 #include <algorithm>
 
 //#include <gtk/gtkfilesel.h>
@@ -71,7 +71,7 @@ void App_WithDoc::on_menu_file_close()
 }
 
 
-bool App_WithDoc::open_document(const Glib::ustring& file_uri)
+bool App_WithDoc::open_document(const Glib::ustring& strFilepath)
 {
   //Check whether it's already open:
   //It could even be open in this instance.
@@ -85,7 +85,7 @@ bool App_WithDoc::open_document(const Glib::ustring& file_uri)
     if(pApp)
     {
       Document* pDoc = pApp->get_document();
-      if(pDoc->get_file_uri() == file_uri)
+      if(pDoc->get_filepath() == strFilepath)
       {
         bAlreadyOpen = true;
         pAppAlreadyOpen = pApp;
@@ -126,31 +126,10 @@ bool App_WithDoc::open_document(const Glib::ustring& file_uri)
     }
 
     //Open it.
-    pApp->m_pDocument->set_file_uri(file_uri);
+    pApp->m_pDocument->set_filepath(strFilepath);
     bool bTest = pApp->m_pDocument->load();
 
-    bool bOpenFailed = false;
     if(!bTest) //if open failed.
-      bOpenFailed = true;
-    else
-    {
-      //if open succeeded then let the App respond:
-      bool test = pApp->on_document_load();
-      if(!test)
-        bOpenFailed = true; //The application didn't like something about the just-loaded document.
-      else
-      {
-        pApp->update_window_title();
-        set_document_modified(false); //disables menu and toolbar Save items.
-
-        //Update document history list:
-        document_history_add(file_uri);
-
-        return true; //success.
-      }
-    }
-
-    if(bOpenFailed)
     {
       ui_warning(gettext("Open failed."));
 
@@ -170,7 +149,18 @@ bool App_WithDoc::open_document(const Glib::ustring& file_uri)
 
       return false; //failed.
     }
-      
+    else
+    {
+      //if open succeeded:
+      pApp->on_document_load();
+      pApp->update_window_title();
+      set_document_modified(false); //disables menu and toolbar Save items.
+
+      //Update document history list:
+      document_history_add(strFilepath);
+
+      return true; //success.
+    }
   } //if already open.
 
   return false; //failed.
@@ -184,9 +174,9 @@ void App_WithDoc::on_menu_file_open()
   ui_bring_to_front();
 
   //Ask user to choose file to open:
-  Glib::ustring file_uri = ui_file_select_open();
-  if(!file_uri.empty())
-    open_document(file_uri);
+  Glib::ustring strFilepath = ui_file_select_open();
+  if(!strFilepath.empty())
+    open_document(strFilepath);
 }
 
 //This is for calling directly, use the other override for the signal handler:
@@ -204,39 +194,29 @@ void App_WithDoc::on_menu_file_saveas()
   ui_bring_to_front();
 
   //Show the save dialog:  
-  const Glib::ustring& file_uriOld = m_pDocument->get_file_uri();
-  Glib::ustring file_uri = ui_file_select_save(file_uriOld);
-  if(!file_uri.empty())
+  const Glib::ustring& strFilepathOld = m_pDocument->get_filepath();
+  Glib::ustring strFilepath = ui_file_select_save(strFilepathOld);
+  if(!strFilepath.empty())
   {
-    //Enforce the file extension:
-    file_uri = m_pDocument->get_file_uri_with_extension(file_uri);
-    
-    bool bUseThisFileUri = true;
+    bool bUseThisFilePath = true;
 
     //Check whether file exists already:
     {
-      // Try to open the input file.
-      Gnome::Vfs::Handle read_handle;
-      try
+      std::ifstream fStream(strFilepath.c_str());
+      if(fStream.is_open())
       {
-        read_handle.open(file_uri, Gnome::Vfs::OPEN_READ);
-
-        //It does (there was no exception), so ask the user to confirm overwrite:
-        bool bOverwrite = ui_ask_overwrite(file_uri);
+        //Ask user to confirm overwrite:
+        bool bOverwrite = ui_ask_overwrite(strFilepath);
 
         //Respond to button that was clicked:
-        bUseThisFileUri = bOverwrite;
-      }
-      catch(const Gnome::Vfs::exception& ex)
-      {
-        bUseThisFileUri = true; //It does not exist.
+        bUseThisFilePath = bOverwrite;
       }
     }
 
     //Save to this filepath:
-    if(bUseThisFileUri)
+    if(bUseThisFilePath)
     {
-      m_pDocument->set_file_uri(file_uri, true); //true = enforce file extension
+      m_pDocument->set_filepath(strFilepath, true); //true = enforce file path
       bool bTest  = m_pDocument->save();
 
       if(!bTest)
@@ -276,7 +256,7 @@ void App_WithDoc::on_menu_file_save()
   if(m_pDocument)
   {
     //If there is already a filepath, then save to that location:
-    if(!(m_pDocument->get_file_uri().empty()))
+    if(!(m_pDocument->get_filepath().empty()))
     {
       bool bTest = m_pDocument->save();
 
@@ -407,7 +387,7 @@ void App_WithDoc::cancel_close_or_exit()
   //exit_destroy_marked_instances(); //Clean up after an exit.
 }
   
-bool App_WithDoc::on_document_load()
+void App_WithDoc::on_document_load()
 {        
   //Show document contents:
   if(m_pDocument)
@@ -418,11 +398,7 @@ bool App_WithDoc::on_document_load()
 
     //Set document as unmodified (this could have been wrongly set during the load):
     set_document_modified(false);
-
-    return true;
   }
-  else
-    return false; //I can't think of any reason why this would happen.
   
   //If you are not using Views, then override this to fill your various windows with stuff according to the contents of the document.
 }
@@ -432,7 +408,7 @@ void App_WithDoc::update_window_title()
 
 }
 
-void App_WithDoc::on_document_modified(bool modified)
+void App_WithDoc::on_document_modified()
 {
   //Change the displayed 'modified' status.
   //This method could be overridden to e.g. enable a Save icon or enable the Save menu item.
@@ -478,7 +454,7 @@ void App_WithDoc::after_successful_save()
   set_document_modified(false); //enables/disables menu and toolbar widgets.
     
   //Update document history list:
-  document_history_add(m_pDocument->get_file_uri());     
+  document_history_add(m_pDocument->get_filepath());     
 }
 
 Glib::ustring App_WithDoc::get_conf_fullkey(const Glib::ustring& key)
@@ -487,12 +463,12 @@ Glib::ustring App_WithDoc::get_conf_fullkey(const Glib::ustring& key)
 }
 
 
-void App_WithDoc::document_history_add(const Glib::ustring& file_uri)
+void App_WithDoc::document_history_add(const Glib::ustring& strFilepath)
 {
   //Override this.
 }
 
-void App_WithDoc::document_history_remove(const Glib::ustring& file_uri)
+void App_WithDoc::document_history_remove(const Glib::ustring& strFilepath)
 {
   //Override this.
 }
