@@ -28,7 +28,7 @@ SubView1::SubView1()
   pack_start(m_Entry);
 
   //Connect signals:
-  m_Entry.signal_changed().connect(SigC::slot(*this, &SubView1::on_Entry_changed));
+  m_Entry.signal_changed().connect(sigc::mem_fun(*this, &SubView1::on_Entry_changed));
  
   show_all();
 }
